@@ -149,7 +149,8 @@ e_html_editor_get_parent_block_node_from_child (WebKitDOMNode *node)
 	    element_has_tag (WEBKIT_DOM_ELEMENT (parent), "u"))
 		parent = webkit_dom_node_get_parent_node (parent);
 
-	if (element_has_class (WEBKIT_DOM_ELEMENT (parent), "-x-evo-quoted"))
+	if (element_has_class (WEBKIT_DOM_ELEMENT (parent), "-x-evo-quoted") ||
+	    element_has_class (WEBKIT_DOM_ELEMENT (parent), "Apple-tab-span"))
 		parent = webkit_dom_node_get_parent_node (parent);
 
 	return parent;
@@ -314,8 +315,10 @@ remove_node_if_empty (WebKitDOMNode *node)
 }
 
 WebKitDOMNode *
-split_list_into_two (WebKitDOMNode *item)
+split_node_into_two (WebKitDOMNode *item,
+                     gint level)
 {
+	gint current_level = 1;
 	WebKitDOMDocument *document;
 	WebKitDOMDocumentFragment *fragment;
 	WebKitDOMNode *parent, *prev_parent, *tmp;
@@ -356,6 +359,11 @@ split_list_into_two (WebKitDOMNode *item)
 					first_child, sibling, insert_before, NULL);
 			}
 		}
+
+		if (current_level >= level && level >= 0)
+			break;
+
+		current_level++;
 	}
 
 	tmp = webkit_dom_node_insert_before (
